summaryrefslogtreecommitdiff
path: root/recording.h
diff options
context:
space:
mode:
Diffstat (limited to 'recording.h')
-rw-r--r--recording.h21
1 files changed, 9 insertions, 12 deletions
diff --git a/recording.h b/recording.h
index 5a5e8de..eeea560 100644
--- a/recording.h
+++ b/recording.h
@@ -1,10 +1,10 @@
/*
* recording.h: Recording file handling
*
- * See the main source file 'osm.c' for copyright information and
+ * See the main source file 'vdr.c' for copyright information and
* how to reach the author.
*
- * $Id: recording.h 1.2 2000/04/14 15:12:42 kls Exp $
+ * $Id: recording.h 1.6 2000/04/24 09:45:49 kls Exp $
*/
#ifndef __RECORDING_H
@@ -12,15 +12,17 @@
#include <time.h>
#include "config.h"
-#include "dvbapi.h"
#include "tools.h"
void AssertFreeDiskSpace(void);
class cRecording : public cListObject {
-public:
- char *name;
+ friend class cRecordings;
+private:
+ char *titleBuffer;
char *fileName;
+ char *name;
+public:
time_t start;
int priority;
int lifetime;
@@ -29,18 +31,13 @@ public:
cRecording(const char *FileName);
~cRecording();
const char *FileName(void);
+ const char *Title(char Delimiter = ' ');
bool Delete(void);
// Changes the file name so that it will no longer be visible in the OSM
// Returns false in case of error
bool Remove(void);
// Actually removes the file from the disk
// Returns false in case of error
- bool Record(void);
- // Starts recording of the file
- bool Play(void);
- // Starts playback of the file
- void Stop(void);
- // Stops recording or playback of the file
};
class cRecordings : public cList<cRecording> {
@@ -29,18 +31,13 @@ public:
bool Delete(void);
- // Changes the file name so that it will no longer be visible in the OSM
+ // Changes the file name so that it will no longer be visible in the "Recordings" menu
// Returns false in case of error
bool Remove(void);